/***************************************************************************//**
 *   @file   AD5162.c
 *   @brief  Implementation of AD5162 Driver.
 *   @author Dan Nechita
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 549
*******************************************************************************/

/******************************************************************************/
/* Include Files                                                              */
/******************************************************************************/
#include "AD5162.h"			    // AD5162 definitions.
#include "Communication.h"		// Communication definitions.

/**************************************************************************//**
 * @brief Initialize SPI.
 *
 * @return 1.
******************************************************************************/
unsigned char AD5162_Init(void)
{
    ADI_PART_CS_PIN_OUT;
    ADI_PART_CS_HIGH;    // Active LOW
    SPI_Init(0, 1000000, 1, 1);
  
    return(1);    
}

/**************************************************************************//**
 * @brief  Send data to one of the 2 channels available.
 *
 * @param address - The address of the channel.
 *                  Example: AD5162_CHANNEL1
 *                           AD5162_CHANNEL2
 * @param data - 8-bit data that is written to the device.
 *
 * @return None
******************************************************************************/
void AD5162_SendDataWord(unsigned char address, 
                         unsigned char data)
{
    unsigned char spiWord[3] = {0x01, 0x00, 0x00};
    
    spiWord[1] = address;
    spiWord[2] = data;
    SPI_Write(spiWord, 2);
}
